@@ -30,7 +30,7 @@ our @EXPORT = qw(
     x
 );
 
-our $VERSION = '0.0300';
+our $VERSION = '0.0301';
 
 my $self;
 
@@ -219,10 +219,9 @@ Default: C<64>
 
 =head2 w
 
-Write score.  Supply a string argument to set and use a different
-B<filename>.
+Write score to a temporary file.
 
-Default filename: C<idi.mid>
+Supply a string argument to set and use a persistent B<filename>.
 
 =head2 x
 
@@ -235,6 +234,8 @@ No-op (with C<MIDI::Simple::noop>)
 
 =head1 SEE ALSO
 
+L<Exporter>
+
 L<File::Slurper>
 
 L<File::Temp>
